@@ -1,4 +1,4 @@
-/* $Id: xfce-kiosk.h 21064 2006-04-18 19:35:58Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA
  */
 
 #if !defined(LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H) && !defined(LIBXFCE4UTIL_COMPILATION)
@@ -27,10 +27,12 @@
 #define __XFCE_KIOSK_H__
 
 #include <glib.h>
+#include <glib-object.h>
 
-G_BEGIN_DECLS;
+G_BEGIN_DECLS
 
-#define XFCE_KIOSK(obj) ((XfceKiosk *)(obj))
+#define XFCE_TYPE_KIOSK xfce_kiosk_get_type ()
+G_DECLARE_FINAL_TYPE (XfceKiosk, xfce_kiosk, XFCE, KIOSK, GObject)
 
 typedef struct _XfceKiosk XfceKiosk;
 
@@ -40,6 +42,6 @@ gboolean   xfce_kiosk_query (const XfceKiosk *kiosk,
                              const gchar     *capability);
 void       xfce_kiosk_free  (XfceKiosk       *kiosk);
 
-G_END_DECLS;
+G_END_DECLS
 
 #endif /* !__XFCE_KIOSK_H__ */
